@@ -1,7 +1,7 @@
 package App::shcompgen;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -620,14 +620,14 @@ App::shcompgen - Generate shell completion scripts
 
 =head1 VERSION
 
-This document describes version 0.11 of App::shcompgen (from Perl distribution App-shcompgen), released on 2015-08-17.
+This document describes version 0.12 of App::shcompgen (from Perl distribution App-shcompgen), released on 2015-09-03.
 
 =head1 FUNCTIONS
 
 
 =head2 generate(%args) -> [status, msg, result, meta]
 
-{en_US Generate shell completion scripts for detectable programs}.
+Generate shell completion scripts for detectable programs.
 
 Arguments ('*' denotes required arguments):
 
@@ -635,17 +635,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions","/etc/bash_completion.d"])
 
-{en_US Directory to put completions scripts}.
+Directory to put completions scripts.
 
 =item * B<bash_per_user_dir> => I<array[str]>
 
-{en_US Directory to put completions scripts}.
+Directory to put completions scripts.
 
 =item * B<global> => I<bool>
 
-{en_US Use global completions directory}.
+Use global completions directory.
 
-{en_US 
 Shell has global (system-wide) completions directory as well as per-user. For
 example, in fish the global directory is by default C</etc/fish/completions> and
 the per-user directory is C<~/.config/fish/completions>.
@@ -653,33 +652,26 @@ the per-user directory is C<~/.config/fish/completions>.
 By default, if running as root, the global is chosen. And if running as normal
 user, per-user directory is chosen. Using C<--global> or C<--per-user> overrides
 that and manually select which.
-}
 
 =item * B<prog> => I<array[str]>
 
-{en_US Program(s) to generate completion for}.
+Program(s) to generate completion for.
 
-{en_US 
 Can contain path (e.g. C<../foo>) or a plain word (C<foo>) in which case will be
 searched from PATH.
-}
 
 =item * B<replace> => I<bool>
 
-{en_US Replace existing script}.
+Replace existing script.
 
-{en_US 
 The default behavior is to skip if an existing completion script exists.
-}
 
 =item * B<shell> => I<str>
 
-{en_US Override autodetection and select shell manually}.
+Override autodetection and select shell manually.
 
-{en_US 
 The default is to look at your SHELL environment variable value. If it is
 undefined, the default is C<bash>.
-}
 
 =back
 
@@ -697,12 +689,10 @@ Return value:  (any)
 
 =head2 init(%args) -> [status, msg, result, meta]
 
-{en_US Initialize shcompgen}.
+Initialize shcompgen.
 
-{en_US 
 This subcommand creates the completion directories and initialization shell
 script, as well as run C<generate>.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -710,17 +700,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions","/etc/bash_completion.d"])
 
-{en_US Directory to put completions scripts}.
+Directory to put completions scripts.
 
 =item * B<bash_per_user_dir> => I<array[str]>
 
-{en_US Directory to put completions scripts}.
+Directory to put completions scripts.
 
 =item * B<global> => I<bool>
 
-{en_US Use global completions directory}.
+Use global completions directory.
 
-{en_US 
 Shell has global (system-wide) completions directory as well as per-user. For
 example, in fish the global directory is by default C</etc/fish/completions> and
 the per-user directory is C<~/.config/fish/completions>.
@@ -728,16 +717,13 @@ the per-user directory is C<~/.config/fish/completions>.
 By default, if running as root, the global is chosen. And if running as normal
 user, per-user directory is chosen. Using C<--global> or C<--per-user> overrides
 that and manually select which.
-}
 
 =item * B<shell> => I<str>
 
-{en_US Override autodetection and select shell manually}.
+Override autodetection and select shell manually.
 
-{en_US 
 The default is to look at your SHELL environment variable value. If it is
 undefined, the default is C<bash>.
-}
 
 =back
 
@@ -755,7 +741,7 @@ Return value:  (any)
 
 =head2 list(%args) -> [status, msg, result, meta]
 
-{en_US List all shell completion scripts generated by this script}.
+List all shell completion scripts generated by this script.
 
 Arguments ('*' denotes required arguments):
 
@@ -763,19 +749,18 @@ Arguments ('*' denotes required arguments):
 
 =item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions","/etc/bash_completion.d"])
 
-{en_US Directory to put completions scripts}.
+Directory to put completions scripts.
 
 =item * B<bash_per_user_dir> => I<array[str]>
 
-{en_US Directory to put completions scripts}.
+Directory to put completions scripts.
 
 =item * B<detail> => I<bool>
 
 =item * B<global> => I<bool>
 
-{en_US Use global completions directory}.
+Use global completions directory.
 
-{en_US 
 Shell has global (system-wide) completions directory as well as per-user. For
 example, in fish the global directory is by default C</etc/fish/completions> and
 the per-user directory is C<~/.config/fish/completions>.
@@ -783,16 +768,13 @@ the per-user directory is C<~/.config/fish/completions>.
 By default, if running as root, the global is chosen. And if running as normal
 user, per-user directory is chosen. Using C<--global> or C<--per-user> overrides
 that and manually select which.
-}
 
 =item * B<shell> => I<str>
 
-{en_US Override autodetection and select shell manually}.
+Override autodetection and select shell manually.
 
-{en_US 
 The default is to look at your SHELL environment variable value. If it is
 undefined, the default is C<bash>.
-}
 
 =back
 
@@ -810,7 +792,7 @@ Return value:  (any)
 
 =head2 remove(%args) -> [status, msg, result, meta]
 
-{en_US Remove shell completion scripts generated by this script}.
+Remove shell completion scripts generated by this script.
 
 Arguments ('*' denotes required arguments):
 
@@ -818,17 +800,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions","/etc/bash_completion.d"])
 
-{en_US Directory to put completions scripts}.
+Directory to put completions scripts.
 
 =item * B<bash_per_user_dir> => I<array[str]>
 
-{en_US Directory to put completions scripts}.
+Directory to put completions scripts.
 
 =item * B<global> => I<bool>
 
-{en_US Use global completions directory}.
+Use global completions directory.
 
-{en_US 
 Shell has global (system-wide) completions directory as well as per-user. For
 example, in fish the global directory is by default C</etc/fish/completions> and
 the per-user directory is C<~/.config/fish/completions>.
@@ -836,25 +817,20 @@ the per-user directory is C<~/.config/fish/completions>.
 By default, if running as root, the global is chosen. And if running as normal
 user, per-user directory is chosen. Using C<--global> or C<--per-user> overrides
 that and manually select which.
-}
 
 =item * B<prog> => I<array[str]>
 
-{en_US Program(s) to remove completion script of}.
+Program(s) to remove completion script of.
 
-{en_US 
 Can contain path (e.g. C<../foo>) or a plain word (C<foo>) in which case will be
 searched from PATH.
-}
 
 =item * B<shell> => I<str>
 
-{en_US Override autodetection and select shell manually}.
+Override autodetection and select shell manually.
 
-{en_US 
 The default is to look at your SHELL environment variable value. If it is
 undefined, the default is C<bash>.
-}
 
 =back
 
